# OpenGPT

A framework for making grounded instruction based datasets and training domain expert ChatGPT like models.


### How to

1. Collect a dataset
2. Write a prompt or use an existing prompt from the ./data/prompts.txt
3. Make a copy of the config.yaml file in ./data/ and make the necessary changes. Use the Prompt creation notebook from ./experiments
4. Create dataset using the Dataset Generation notebook from ./experiments
